@@ -19,8 +19,6 @@
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 #  USA
 
-from __future__ import print_function
-
 import os
 import subprocess
 
@@ -56,7 +54,6 @@ RELEASE_MAP = {
     'xena': 'focal',
     'yoga': 'focal',
     'zed': 'jammy',
-    'antelope': 'jammy',
 }
 UCA = "Ubuntu Cloud Archive"
 WEB_LINK = 'https://wiki.ubuntu.com/OpenStack/CloudArchive'
@@ -168,4 +165,3 @@ class CloudArchiveShortcutHandler(ShortcutHandler):
 
         self._set_source_entry(handler.SourceEntry().line)
         return True
-
