@@ -17,7 +17,7 @@ export LC_ALL
 readonly SCRIPTNAME="${0##*/}" # general name of this script
 #
 readonly DATETIME="$(date +%Y-%m-%d-%H-%M-%S 2>/dev/null)"
-readonly DOCKER=$(if type -t docker >/dev/null; then echo "YES"; else echo "NO"; fi)
+readonly DOCKER=$(if type docker >/dev/null; then echo "YES"; else echo "NO"; fi)
 readonly HW="$(uname -i 2>/dev/null)"
 # retrieve and split kernel version
 readonly KERNEL_BASE="$(uname -r 2>/dev/null)"
@@ -25,7 +25,7 @@ readonly KERNEL_VERSION=$(echo ${KERNEL_BASE} | cut -d'.' -f1 )
 readonly KERNEL_MAJOR_REVISION=$(echo ${KERNEL_BASE} | cut -d'.' -f2 )
 readonly KERNEL_MINOR_REVISION=$(echo ${KERNEL_BASE} | cut -d'.' -f3 | sed 's/[^0-9].*//g')
 readonly KERNEL_INFO=${KERNEL_VERSION}.${KERNEL_MAJOR_REVISION}.${KERNEL_MINOR_REVISION}
-readonly KVM=$(if type -t virsh >/dev/null; then echo "YES"; else echo "NO"; fi)
+readonly KVM=$(if type virsh >/dev/null; then echo "YES"; else echo "NO"; fi)
 # The file to indicate that another instance of the script is already running
 readonly LOCKFILE="/tmp/${SCRIPTNAME}.lock"
 # check limits for logfiles like /var/log/messages
@@ -61,7 +61,7 @@ paramWORKDIR_BASE="/tmp"  # initial default path
 # print dbginfo.sh version info
 print_version() {
 	cat <<EOF
-${SCRIPTNAME}: Debug information script version 2.20.0-build-20220623
+${SCRIPTNAME}: Debug information script version 2.23.0-build-20221201
 Copyright IBM Corp. 2002, 2022
 EOF
 }
@@ -382,6 +382,7 @@ CONFIGFILES="\
   /etc/lvm\
   /etc/modprobe.conf*\
   /etc/modprobe.d\
+  /etc/modules-load.d/*.conf\
   /etc/mtab\
   /etc/multipath\
   /etc/network\
@@ -402,9 +403,16 @@ CONFIGFILES="\
   /etc/systemd\
   /etc/udev*\
   /etc/xinet.d\
+  /lib/modprobe.d\
   $(find /lib/modules -name modules.dep 2>/dev/null)\
   /lib/systemd/system/docker.service\
+  /usr/lib/modprobe.d\
+  /usr/lib/modules-load.d/*.conf\
   /usr/lib/systemd/system\
+  /usr/local/lib/modprobe.d\
+  /usr/local/lib/modules-load.d/*.conf\
+  /run/modprobe.d\
+  /run/modules-load.d/*.conf\
   /run/udev/chreiplzfcpmp-ipl-volume-id\
   /run/udev/rules.d\
   "
@@ -427,7 +435,7 @@ CMDS="uname -a\
   :systemctl --all --no-pager list-unit-files\
   :systemd-delta\
   :ulimit -a\
-  :env\
+  :env --null | sort --zero-terminated | tr '\000' '\n'\
   :find /boot -print0 | sort -z | xargs -0 -n 10 ls -ld\
   :find /var/crash -print0 | sort -z | xargs -0 -n 10 ls -ld\
   :df -h\
@@ -442,7 +450,7 @@ CMDS="${CMDS}\
   :lszdev\
   :find /dev -print0 | sort -z | xargs -0 -n 10 ls -ld\
   :lspci -t\
-  :lspci -vv\
+  :lspci -vvv\
   :lstape\
   :smc_dbg\
   "
@@ -463,6 +471,7 @@ CMDS="${CMDS}\
   :multipathd -k'show maps'\
   :multipathd -k'show topo'\
   :multipathd -k'show paths'\
+  :multipathd -k'show paths format %w|%a|%r|%L|%p|%i|%d|%D|%t|%T|%o|%0|%C' | sort\
   :multipathd -k'show maps stats'\
   :multipathd -k'show maps status'\
   :multipathd -k'show status'\
@@ -673,12 +682,12 @@ collect_vmcmdsout() {
 	if echo "${RUNTIME_ENVIRONMENT}" | grep -qi "z/VM" >/dev/null 2>&1; then
 		pr_collect_output "z/VM"
 
-		if type -t vmcp >/dev/null; then
+		if type vmcp >/dev/null; then
 			cp_command="vmcp"
 			if ! lsmod 2>/dev/null | grep -q vmcp && modinfo vmcp >/dev/null 2>&1; then
 				modprobe vmcp && module_loaded=0 && sleep 2
 			fi
-		elif type -t hcp >/dev/null; then
+		elif type hcp >/dev/null; then
 			cp_command="hcp"
 			if ! lsmod 2>/dev/null | grep -q cpint; then
 				modprobe cpint && module_loaded=0 && sleep 2
@@ -772,11 +781,12 @@ collect_sysfs() {
 	# files known to block on read (-x). Stop reading a file that takes
 	# more than 5 seconds (-T 5) such as an active ftrace buffer.
 	# error messages are not written to the log
-	if type -t dump2tar >/dev/null; then
+	if type dump2tar >/dev/null; then
 		dump2tar /sys -z -o "${OUTPUT_FILE_SYSFS}.tgz" \
 		    -x '*/tracing/trace_pipe*' \
 		    -x '*/page_idle/bitmap*' \
 		    -x '*/tracing/per_cpu/*' \
+		    -x '*/tracing/free_buffer' \
 		    --ignore-failed-read -J 1 -T 5 2>>${OUTPUT_FILE_SYSFS}.err
 		rc=$?
 	else
@@ -803,6 +813,7 @@ collect_sysfs() {
 		    -a -not \( -path '*tracing*' -a -name "trace_pipe*" \) \
 		    -a -not \( -path '*page_idle*' -a -name 'bitmap*' \) \
 		    -a -not -path '*tracing/per_cpu*' \
+		    -a -not -path '*/tracing/free_buffer' \
 		    2>/dev/null | while IFS= read -r file_name; do
 			echo " ${file_name}"
 			if ! dd if="${file_name}" status=noxfer iflag=nonblock \
@@ -848,7 +859,7 @@ collect_osaoat() {
 
 	network_devices=$(lsqeth 2>/dev/null | grep "Device name" \
 		     | sed 's/D.*:[[:space:]]*\([^[:space:]]*\)[[:space:]]\+/\1/g')
-	if type -t qethqoat >/dev/null; then
+	if type qethqoat >/dev/null; then
 		if test -n "${network_devices}"; then
 			pr_collect_output "osa oat"
 			for network_device in ${network_devices}; do
@@ -871,7 +882,7 @@ collect_ethtool() {
 	local network_device
 
 	network_devices=$(ls /sys/class/net 2>/dev/null)
-	if type -t ethtool >/dev/null; then
+	if type ethtool >/dev/null; then
 		if test -n "${network_devices}"; then
 			pr_collect_output "ethtool"
 			for network_device in ${network_devices}; do
@@ -912,7 +923,7 @@ collect_tc() {
 	local network_device
 
 	network_devices=$(ls /sys/class/net 2>/dev/null)
-	if type -t tc >/dev/null; then
+	if type tc >/dev/null; then
 		if test -n "${network_devices}"; then
 			pr_collect_output "Trafic Control"
 			for network_device in ${network_devices}; do
@@ -933,7 +944,7 @@ collect_bridge() {
 	local network_device
 
 	network_devices=$(ls /sys/class/net 2>/dev/null)
-	if type -t bridge >/dev/null; then
+	if type bridge >/dev/null; then
 		if test -n "${network_devices}"; then
 			pr_collect_output "bridge"
 			for network_device in ${network_devices}; do
@@ -965,7 +976,7 @@ collect_ovs() {
 		:ovs-vsctl -t 5 show\
 		:ovsdb-client dump\
 		"
-	if type -t ovs-vsctl >/dev/null; then
+	if type ovs-vsctl >/dev/null; then
 		pr_collect_output "OpenVSwitch"
 		IFS=:
 		for ovscmd in ${ovscmds}; do
@@ -1028,7 +1039,7 @@ collect_docker() {
 collect_nvme() {
 	local device
 
-	if type -t nvme >/dev/null; then
+	if type nvme >/dev/null; then
 		pr_collect_output "NVME storage"
 		call_run_command "nvme list" "${OUTPUT_FILE_NVME}"
 		for device in /dev/nvme[0-9]*; do
@@ -1128,21 +1139,22 @@ call_run_command() {
 	local rc=0
 	local cmd="${1}"
 	local logfile="${2}"
-	# extract the raw_command and set cmd_type
-	local raw_cmd=$(echo "${cmd}" | sed -ne 's/^\([^[:space:]]*\).*$/\1/p')
-	local cmd_type=$(type -t ${raw_cmd})
+	# extract the raw_command and set cmd_type, as some shell might split into
+	# several lines restrict the cmd echo to the first line only
+	local raw_cmd=$(echo "${cmd}" | head -1 | sed -ne 's/^\([^[:space:]]*\).*$/\1/p')
+	local cmd_type=$(type ${raw_cmd} | cut -d' ' -sf4,5)
 	# timeout_ok - like a boolean - is not empty if command exists
-	local timeout_ok=$(type -t timeout)
+	local timeout_ok=$(type timeout)
 
 	echo "#######################################################" >> "${logfile}"
 	echo "${USER}@${SYSTEMHOSTNAME:-localhost}> ${cmd}" >> "${logfile}"
 
 	# check calling command type
-	if [ "X${cmd_type}" = "Xbuiltin" ]; then
+	if [ "X${cmd_type}" = "Xshell builtin" ]; then
 		# command is a builtin (no use of timeout possible)
 		eval "${cmd}" >> ${logfile} 2>&1
 		rc=$?
-	elif [ "X${cmd_type}" != "X" ]; then
+	elif [ "X${cmd_type}" != "Xnot found" ]; then
 		if [ "X${timeout_ok}" = "Xfile" ]; then
 			eval timeout -k ${TOS} ${TOS} "${cmd}" >> ${logfile} 2>&1
 			rc=$?
